@@ -886,7 +886,89 @@ namespace anyks {
 					// Создаём объект бинарного контейнера
 					ablm_t ablm(alphabet.convert(filename), alm.get(), &alphabet, &tokenizer, (!logfile.empty() ? logfile.c_str() : nullptr));
 					// Если метеданные получены
-					if(!meta.empty()) ablm.setMeta(json::parse(alphabet.convert(meta)));
+					if(!meta.empty()){
+						// Выполняем конвертацию метаданных
+						json data = json::parse(alphabet.convert(meta));
+						// Если тип шифрования передан
+						if(data.contains("aes") && data.at("aes").is_number()){
+							// Тип шифрования
+							u_int type = 0;
+							// Извлекаем тип шифрования
+							data.at("aes").get_to(type);
+							// Если размер шифрования получен
+							switch(type){
+								// Если это 128-и битное шифрование
+								case 128: ablm.setAES(aspl_t::types_t::aes128); break;
+								// Если это 192-х битное шифрование
+								case 192: ablm.setAES(aspl_t::types_t::aes192); break;
+								// Если это 256-и битное шифрование
+								case 256: ablm.setAES(aspl_t::types_t::aes256); break;
+							}
+						}
+						// Если название словаря передано
+						if(data.contains("name") && data.at("name").is_string()){
+							// Название словаря
+							string name = "";
+							// Извлекаем название словаря
+							data.at("name").get_to(name);
+							// Устанавливаем название словаря
+							if(!name.empty()) ablm.setName(name);
+						}
+						// Если имя автора передано
+						if(data.contains("author") && data.at("author").is_string()){
+							// Имя автора
+							string author = "";
+							// Извлекаем имя автора
+							data.at("author").get_to(author);
+							// Устанавливаем имя автора
+							if(!author.empty()) ablm.setAuthor(author);
+						}
+						// Если тип лицензии передан
+						if(data.contains("lictype") && data.at("lictype").is_string()){
+							// Тип лицензии
+							string lictype = "";
+							// Извлекаем тип лицензии
+							data.at("lictype").get_to(lictype);
+							// Устанавливаем тип лицензии
+							if(!lictype.empty()) ablm.setLictype(lictype);
+						}
+						// Если текст лицензии передан
+						if(data.contains("lictext") && data.at("lictext").is_string()){
+							// Текст лицензии
+							string lictext = "";
+							// Извлекаем текст лицензии
+							data.at("lictext").get_to(lictext);
+							// Устанавливаем текст лицензии
+							if(!lictext.empty()) ablm.setLictext(lictext);
+						}
+						// Если контактные данные переданы
+						if(data.contains("contacts") && data.at("contacts").is_string()){
+							// Контактные данные
+							string contacts = "";
+							// Извлекаем контактные данные
+							data.at("contacts").get_to(contacts);
+							// Устанавливаем контакнтые данные
+							if(!contacts.empty()) ablm.setContacts(contacts);
+						}
+						// Если пароль шифрования контейнера передан
+						if(data.contains("password") && data.at("password").is_string()){
+							// Пароль контейнера
+							string password = "";
+							// Извлекаем пароль контейнера
+							data.at("password").get_to(password);
+							// Устанавливаем пароль контейнера
+							if(!password.empty()) ablm.setPassword(password);
+						}
+						// Если копирайт контейнера передан
+						if(data.contains("copyright") && data.at("copyright").is_string()){
+							// Копирайт контейнера
+							string copyright = "";
+							// Извлекаем копирайт контейнера
+							data.at("copyright").get_to(copyright);
+							// Устанавливаем копирайт контейнера
+							if(!copyright.empty()) ablm.setCopyright(copyright);
+						}
+					}
 					// Выполняем инициализацию словаря
 					ablm.init();
 					// Выполняем чтение бинарных данных
@@ -1020,6 +1102,16 @@ namespace anyks {
 			// Выполняем проверку существования последовательности
 			return alm->check(seq, accurate);
 		}
+		/**
+		 * checkSequence Метод проверки существования последовательности
+		 * @param seq      список слов последовательности
+		 * @param accurate режим точной проверки
+		 * @return         результат проверки
+		 */
+		const pair <bool, size_t> checkSequence(const vector <wstring> & seq, const bool accurate = false) noexcept {
+			// Выполняем проверку существования последовательности
+			return alm->check(seq, accurate);
+		}
 		/**
 		 * sentencesToFile Метод сборки указанного количества предложений и записи в файл
 		 * @param counts   количество предложений для сборки
@@ -1061,6 +1153,14 @@ namespace anyks {
 			// Выполняем проверку существования последовательности
 			alm->checkByFiles(alphabet.convert(path), alphabet.convert(filename), accurate, nullptr, alphabet.convert(ext));
 		}
+		/**
+		 * setTokenizerFn Метод установки функции внешнего токенизатора
+		 * @param fn функция внешнего токенизатора
+		 */
+		void setTokenizerFn(function <void (const wstring &, function <const bool (const wstring &, const vector <string> &, const bool, const bool)>)> fn) noexcept {
+			// Устанавливаем функцию внешнего токенизатора
+			tokenizer.setExternal(fn);
+		}
 	};
 };
 // alm Регистрируем имя модуля языковой модели
@@ -1210,6 +1310,8 @@ PYBIND11_MODULE(alm, m) {
 		.def("setAllTokenDisable", &anyks::Methods::setAllTokenDisable, "Method for set all tokens as unidentifiable")
 		// setTokensUnknown Метод установки списка токенов приводимых к <unk>
 		.def("setTokensUnknown", &anyks::Methods::setTokensUnknown, "Method for set the list of tokens cast to <unk>")
+		// setTokenizerFn Метод установки функции внешнего токенизатора
+		.def("setTokenizerFn", &anyks::Methods::setTokenizerFn, "Method for set the function of an external tokenizer")
 		// getTokensDisable Метод извлечения списка запрещённых токенов
 		.def("getTokensDisable", &anyks::Methods::getTokensDisable, "Method for retrieving the list of forbidden tokens")
 		// countLetter Метод подсчета количества указанной буквы в слове
@@ -1306,6 +1408,8 @@ PYBIND11_MODULE(alm, m) {
 		.def("delInText", overload_cast_ <const wstring &, const anyks::wdel_t> ()(&anyks::Methods::delInText), "Method for delete letter in text", py::arg("text") = L"", py::arg("flag") = anyks::wdel_t::broken)
 		// checkSequence Метод проверки существования последовательности
 		.def("checkSequence", overload_cast_ <const vector <size_t> &, const bool> ()(&anyks::Methods::checkSequence), "Sequence Existence Method", py::arg("seq") = vector <size_t> (), py::arg("accurate") = false)
+		// checkSequence Метод проверки существования последовательности
+		.def("checkSequence", overload_cast_ <const vector <wstring> &, const bool> ()(&anyks::Methods::checkSequence), "Sequence Existence Method", py::arg("seq") = vector <wstring> (), py::arg("accurate") = false)
 		// countsByFiles Метод подсчёта количества n-грамм в текстовом файле
 		.def("countsByFiles", &anyks::Methods::countsByFiles, "Method for counting the number of n-grams in a text file", py::arg("path") = L"", py::arg("filename") = L"", py::arg("ngrams") = 0, py::arg("ext") = L"txt")
 		// checkByFiles Метод проверки существования последовательности в текстовом файле
